lol_api library

Classes

AccountDTO
AccountRegionDTO
AccountV1
ActiveShardDTO
ApexPlayerInfoDTO
ApiUtil
Utility class for Riot API calls.
BanDTO
BannedChampion
ChallengeConfigInfoDTO
ChallengeInfo
ChallengePoints
ChampionInfo
ChampionMasteryDTO
This object contains single Champion Mastery information for player and champion combination.
ChampionMasteryV4
ChampionV3
ClashV1
ContentDTO
CurrentGameInfo
CurrentGameParticipant
GameCustomizationObject
InfoDTO
LeagueEntryDTO
LeagueExpV4
LeagueItemDTO
LeagueListDTO
LeagueV4
LevelToPercentile
LobbyEventV5DTO
LobbyEventV5DTOWrapper
LOLChallengesV1
LolRsoMatchV1
LoLStatusV4
MatchDTO
MatchEventDTO
MatchFrameDTO
MatchPositionDTO
MatchTeamDTO
MatchTimelineDTO
MatchTimelineInfoFrameEventVictimDamageReceivedDTO
type should be typed with enum but spec doesn't exists
MatchTimelineInfoFrameParticipantFrameChampionStatsDTO
MatchTimelineInfoFrameParticipantFrameDamageStatsDTO
MatchTimelineInfoFrameParticipantFrameDTO
MatchTimelineInfoFrameParticipantFramesDTO
MatchTimelineInfoParticipantDTO
MatchV5
MetaDataDTO
MiniSeriesDTO
NextSeasonMilestonesDTO
ObjectiveDTO
ObjectivesDTO
Observer
ParticipantDTO
Perks
PerksDTO
PerkStatsDTO
PerkStyleDTO
PerkStyleSelectionDTO
PlatformDataDTO
PlayerCilentPreferences
PlayerDTO
PlayerInfoDTO
ProviderRegistrationParametersV5
ReplayDTO
RewardConfigDTO
RiotApi
Singleton class for Riot API key.
SerializableMapOfPercentile
For serializable Map<String, Map<Tier, num>> data.
SpectatorV5
StatusDTO
SummonerDTO
SummonerV4
TeamDTO
TournamentCodeParametersV5
TournamentCodeUpdateParametersV5
TournamentCodeV5DTO
TournamentDTO
TournamentGamesV5
TournamentPhaseDTO
TournamentRegistrationParametersV5
TournamentStubV5
TournamentTeamV5
TournamentV5
UpdateDTO

Exceptions / Errors

RiotApiException